@@ -1,14 +1,14 @@
-#' @rdname detectFronts
-#' @method detectFronts matrix
+#' @rdname getGradients
+#' @method getGradients matrix
 #' @export
-detectFronts.matrix <- function(x, method = "BelkinOReilly2009",
+getGradients.matrix <- function(x, method = "BelkinOReilly2009",
                                 intermediate = FALSE, ...){
 
   # Check arguments
   checkArgs_df_matrix(x = x)
 
   # Apply method
-  output <- detectFronts.default(x = x, method = method,
+  output <- getGradients.default(x = x, method = method,
                                  intermediate = intermediate, ...)
 
   dimnames(output) <- dimnames(x)
